@@ -1,9 +1,9 @@
 package Sah::Schema::country::code;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-04'; # DATE
+our $DATE = '2020-03-08'; # DATE
 our $DIST = 'Sah-Schemas-Country'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 use Locale::Codes::Country_Codes ();
 
@@ -50,7 +50,7 @@ Sah::Schema::country::code - Country code (alpha-2 or alpha-3)
 
 =head1 VERSION
 
-This document describes version 0.007 of Sah::Schema::country::code (from Perl distribution Sah-Schemas-Country), released on 2020-03-04.
+This document describes version 0.008 of Sah::Schema::country::code (from Perl distribution Sah-Schemas-Country), released on 2020-03-08.
 
 =head1 SYNOPSIS
 
@@ -64,7 +64,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -86,15 +86,15 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- undef  # INVALID
+ ""  # INVALID
 
- undef  # valid
+ "ID"  # valid, becomes "id"
 
- undef  # valid
+ "IDN"  # valid, becomes "idn"
 
- undef  # INVALID
+ "xx"  # INVALID
 
- undef  # INVALID
+ "xxx"  # INVALID
 
 =head1 DESCRIPTION
 
